namespace elm { namespace menu { 
inline ::efl::eolian::return_traits< ::efl::eina::string_view>::type Item::icon_name_get() const
{
   const char * __return_value =  ::elm_obj_menu_item_icon_name_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::eina::string_view>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Item::icon_name_set( ::efl::eolian::in_traits< ::efl::eina::string_view>::type icon) const
{
    ::elm_obj_menu_item_icon_name_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(icon));
}
inline ::efl::eolian::return_traits<bool>::type Item::selected_get() const
{
   Eina_Bool __return_value =  ::elm_obj_menu_item_selected_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Item::selected_set( ::efl::eolian::in_traits<bool>::type selected) const
{
    ::elm_obj_menu_item_selected_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(selected));
}
inline ::efl::eolian::return_traits< ::elm::widget::Item>::type Item::prev_get() const
{
    ::Elm_Widget_Item* __return_value =  ::elm_obj_menu_item_prev_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::elm::widget::Item>::type>(__return_value);
}
inline ::efl::eolian::return_traits< ::elm::widget::Item>::type Item::next_get() const
{
    ::Elm_Widget_Item* __return_value =  ::elm_obj_menu_item_next_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::elm::widget::Item>::type>(__return_value);
}
inline ::efl::eolian::return_traits< unsigned int>::type Item::index_get() const
{
   unsigned int __return_value =  ::elm_obj_menu_item_index_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< unsigned int>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Item::subitems_clear() const
{
    ::elm_obj_menu_item_subitems_clear(this->_eo_ptr());
}
inline ::efl::eolian::return_traits<  ::efl::eina::range_list< ::elm::widget::Item>>::type Item::subitems_get() const
{
   const Eina_List * __return_value =  ::elm_obj_menu_item_subitems_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<  ::efl::eina::range_list< ::elm::widget::Item>>::type>(__return_value);
}
inline ::efl::eolian::return_traits<bool>::type Item::is_separator() const
{
   Eina_Bool __return_value =  ::elm_obj_menu_item_is_separator(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits< ::efl::canvas::Object>::type Item::object_get() const
{
    ::Efl_Canvas_Object* __return_value =  ::elm_obj_menu_item_object_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::canvas::Object>::type>(__return_value);
}
} } 
namespace eo_cxx {
namespace elm { namespace menu { 
inline ::efl::eolian::return_traits< ::efl::eina::string_view>::type Item::icon_name_get() const
{
   const char * __return_value =  ::elm_obj_menu_item_icon_name_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::eina::string_view>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Item::icon_name_set( ::efl::eolian::in_traits< ::efl::eina::string_view>::type icon) const
{
    ::elm_obj_menu_item_icon_name_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(icon));
}
inline ::efl::eolian::return_traits<bool>::type Item::selected_get() const
{
   Eina_Bool __return_value =  ::elm_obj_menu_item_selected_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Item::selected_set( ::efl::eolian::in_traits<bool>::type selected) const
{
    ::elm_obj_menu_item_selected_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(selected));
}
inline ::efl::eolian::return_traits< ::elm::widget::Item>::type Item::prev_get() const
{
    ::Elm_Widget_Item* __return_value =  ::elm_obj_menu_item_prev_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::elm::widget::Item>::type>(__return_value);
}
inline ::efl::eolian::return_traits< ::elm::widget::Item>::type Item::next_get() const
{
    ::Elm_Widget_Item* __return_value =  ::elm_obj_menu_item_next_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::elm::widget::Item>::type>(__return_value);
}
inline ::efl::eolian::return_traits< unsigned int>::type Item::index_get() const
{
   unsigned int __return_value =  ::elm_obj_menu_item_index_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< unsigned int>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Item::subitems_clear() const
{
    ::elm_obj_menu_item_subitems_clear(this->_eo_ptr());
}
inline ::efl::eolian::return_traits<  ::efl::eina::range_list< ::elm::widget::Item>>::type Item::subitems_get() const
{
   const Eina_List * __return_value =  ::elm_obj_menu_item_subitems_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<  ::efl::eina::range_list< ::elm::widget::Item>>::type>(__return_value);
}
inline ::efl::eolian::return_traits<bool>::type Item::is_separator() const
{
   Eina_Bool __return_value =  ::elm_obj_menu_item_is_separator(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits< ::efl::canvas::Object>::type Item::object_get() const
{
    ::Efl_Canvas_Object* __return_value =  ::elm_obj_menu_item_object_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::canvas::Object>::type>(__return_value);
}
inline elm::menu::Item::operator ::elm::menu::Item() const { return *static_cast< ::elm::menu::Item const*>(static_cast<void const*>(this)); }
inline elm::menu::Item::operator ::elm::menu::Item&() { return *static_cast< ::elm::menu::Item*>(static_cast<void*>(this)); }
inline elm::menu::Item::operator ::elm::menu::Item const&() const { return *static_cast< ::elm::menu::Item const*>(static_cast<void const*>(this)); }
} } }

